@@ -13,8 +13,9 @@ public:
   ~Example_ColorSel() override;
 
 protected:
-  //Signal handler:
+  //Signal handlers:
   void on_button_clicked();
+  void on_dialog_response(int response_id);
 
   //Drawing function:
   void on_drawing_area_draw(const Cairo::RefPtr<Cairo::Context>& cr, int width, int height);
@@ -25,6 +26,7 @@ protected:
   Gtk::DrawingArea m_DrawingArea;
   Gtk::Button m_Button;
   Gdk::RGBA m_Color;
+  std::unique_ptr<Gtk::ColorChooserDialog> m_pDialog;
 };
 
 //Called by DemoWindow;
@@ -41,12 +43,11 @@ Example_ColorSel::Example_ColorSel()
   set_resizable(false);
 
   m_VBox.set_margin(12);
-  add(m_VBox);
+  set_child(m_VBox);
 
   // Create the color swatch area
-  m_Frame.set_shadow_type(Gtk::ShadowType::IN);
   m_Frame.set_expand(true);
-  m_VBox.add(m_Frame);
+  m_VBox.append(m_Frame);
 
   // set a fixed size
   m_DrawingArea.set_content_width(200);
@@ -56,12 +57,12 @@ Example_ColorSel::Example_ColorSel()
   m_Color.set_rgba(0, 0, 1, 1);
   m_DrawingArea.set_draw_func(sigc::mem_fun(*this, &Example_ColorSel::on_drawing_area_draw));
 
-  m_Frame.add(m_DrawingArea);
+  m_Frame.set_child(m_DrawingArea);
 
   m_Button.set_halign(Gtk::Align::END);
   m_Button.set_valign(Gtk::Align::CENTER);
 
-  m_VBox.add(m_Button);
+  m_VBox.append(m_Button);
 
   m_Button.signal_clicked().connect(sigc::mem_fun(*this, &Example_ColorSel::on_button_clicked));
 }
@@ -72,17 +73,27 @@ Example_ColorSel::~Example_ColorSel()
 
 void Example_ColorSel::on_button_clicked()
 {
-  Gtk::ColorChooserDialog dialog("Changing color");
-  dialog.set_transient_for(*this);
-  dialog.set_rgba(m_Color);
-
-  const int response = dialog.run();
-
-  if(response == Gtk::ResponseType::OK)
+  if (!m_pDialog)
   {
-    m_Color = dialog.get_rgba();
+    m_pDialog.reset(new Gtk::ColorChooserDialog("Changing color"));
+    m_pDialog->set_transient_for(*this);
+    m_pDialog->set_hide_on_close(true);
+    m_pDialog->set_modal(true);
+    m_pDialog->signal_response().connect(
+      sigc::mem_fun(*this, &Example_ColorSel::on_dialog_response));
+  }
+  m_pDialog->set_rgba(m_Color);
+  m_pDialog->show();
+}
+
+void Example_ColorSel::on_dialog_response(int response_id)
+{
+  if (response_id == Gtk::ResponseType::OK)
+  {
+    m_Color = m_pDialog->get_rgba();
     m_DrawingArea.queue_draw();
   }
+  m_pDialog->hide();
 }
 
 void Example_ColorSel::on_drawing_area_draw(const Cairo::RefPtr<Cairo::Context>& cr, int, int)
