@@ -30,11 +30,14 @@ protected:
   void start_progressive_loading();
 
   //Signal handlers:
-  bool on_timeout();
+  void on_animation_timeout();
+  bool on_progressive_timeout();
   void on_loader_area_prepared();
   void on_loader_area_updated(int x, int y, int width, int height);
   void on_toggle_sensitivity();
 
+  void init_message_dialog();
+
   //Member widgets:
   Gtk::Box m_BaseVBox;
   Gtk::Box m_HBox;
@@ -42,6 +45,7 @@ protected:
   Gtk::Frame m_Frame_Image;
   Gtk::Label m_Label_Animation;
   Gtk::Frame m_Frame_Animation;
+  Gtk::Picture m_Picture_Animation;
   Gtk::Label m_Label_ThemedIcon;
   Gtk::Frame m_Frame_ThemedIcon;
   Gtk::Label m_Label_Progressive;
@@ -52,8 +56,10 @@ protected:
   Gtk::Label m_Label_Paintable;
   Gtk::ToggleButton m_ToggleButton;
 
+  Glib::RefPtr<Gdk::PixbufAnimationIter> m_refPixbufAnimationIter;
   Glib::RefPtr<Gdk::PixbufLoader> m_refPixbufLoader;
   Glib::RefPtr<Gio::InputStream> m_image_stream;
+  std::unique_ptr<Gtk::MessageDialog> m_pMessageDialog;
 };
 
 //Called by DemoWindow;
@@ -72,100 +78,98 @@ Example_Images::Example_Images()
   set_title("Images");
 
   m_BaseVBox.set_margin(16);
-  add(m_BaseVBox);
-  m_BaseVBox.add(m_HBox);
+  set_child(m_BaseVBox);
+  m_BaseVBox.append(m_HBox);
 
   /* Image */
 
   auto pVBox = Gtk::make_managed<Gtk::Box>(Gtk::Orientation::VERTICAL, 8);
-  m_HBox.add(*pVBox);
+  m_HBox.append(*pVBox);
 
   m_Label_Image.set_markup("<u>Image loaded from a file</u>");
-  pVBox->add(m_Label_Image);
+  pVBox->append(m_Label_Image);
 
-  m_Frame_Image.set_shadow_type(Gtk::ShadowType::IN);
   m_Frame_Image.set_halign(Gtk::Align::CENTER);
   m_Frame_Image.set_valign(Gtk::Align::CENTER);
-  pVBox->add(m_Frame_Image);
+  pVBox->append(m_Frame_Image);
 
   auto pImage = Gtk::make_managed<Gtk::Image>();
   pImage->set_from_icon_name("gtk3-demo");
   pImage->set_icon_size(Gtk::IconSize::LARGE);
-  m_Frame_Image.add(*pImage);
+  m_Frame_Image.set_child(*pImage);
 
   /* Animation */
 
-  m_Label_Animation.set_markup("<u>Animation loaded from a file</u>");
-  pVBox->add(m_Label_Animation);
+  m_Label_Animation.set_markup("<u>Animation loaded from a resource</u>");
+  pVBox->append(m_Label_Animation);
 
-  m_Frame_Animation.set_shadow_type(Gtk::ShadowType::IN);
   m_Frame_Animation.set_halign(Gtk::Align::CENTER);
   m_Frame_Animation.set_valign(Gtk::Align::CENTER);
-  pVBox->add(m_Frame_Animation);
+  pVBox->append(m_Frame_Animation);
 
-  auto pPicture = Gtk::make_managed<Gtk::Picture>();
-  pPicture->set_resource("/images/floppybuddy.gif");
-  m_Frame_Animation.add(*pPicture);
+  auto animation = Gdk::PixbufAnimation::create_from_resource("/images/floppybuddy.gif");
+  m_refPixbufAnimationIter = animation->get_iter();
+  m_Frame_Animation.set_child(m_Picture_Animation);
+
+  // Fill in the first pixbuf and start a timer.
+  on_animation_timeout();
 
   /* Symbolic themed icon */
 
   m_Label_ThemedIcon.set_markup("<u>Symbolic themed icon</u>");
-  pVBox->add(m_Label_ThemedIcon);
+  pVBox->append(m_Label_ThemedIcon);
 
-  m_Frame_ThemedIcon.set_shadow_type(Gtk::ShadowType::IN);
   m_Frame_ThemedIcon.set_halign(Gtk::Align::CENTER);
   m_Frame_ThemedIcon.set_valign(Gtk::Align::CENTER);
-  pVBox->add(m_Frame_ThemedIcon);
+  pVBox->append(m_Frame_ThemedIcon);
 
   auto icon = Gio::ThemedIcon::create("battery-caution-charging-symbolic", true);
   pImage = Gtk::make_managed<Gtk::Image>(icon);
   pImage->set_icon_size(Gtk::IconSize::LARGE);
-  m_Frame_ThemedIcon.add(*pImage);
+  m_Frame_ThemedIcon.set_child(*pImage);
 
   /* Progressive */
 
   pVBox = Gtk::make_managed<Gtk::Box>(Gtk::Orientation::VERTICAL, 8);
-  m_HBox.add(*pVBox);
+  m_HBox.append(*pVBox);
 
   m_Label_Progressive.set_markup("<u>Progressive image loading</u>");
-  pVBox->add(m_Label_Progressive);
+  pVBox->append(m_Label_Progressive);
 
-  m_Frame_Progressive.set_shadow_type(Gtk::ShadowType::IN);
   m_Frame_Progressive.set_halign(Gtk::Align::CENTER);
   m_Frame_Progressive.set_valign(Gtk::Align::CENTER);
-  pVBox->add(m_Frame_Progressive);
+  pVBox->append(m_Frame_Progressive);
 
   /* Create an empty image for now; the progressive loader
    * will create the pixbuf and fill it in.
    */
-  m_Frame_Progressive.add(m_Picture_Progressive);
+  m_Frame_Progressive.set_child(m_Picture_Progressive);
 
   start_progressive_loading();
 
   /* Video */
 
   m_Label_Video.set_markup("<u>Displaying video</u>");
-  pVBox->add(m_Label_Video);
+  pVBox->append(m_Label_Video);
 
-  m_Frame_Video.set_shadow_type(Gtk::ShadowType::IN);
   m_Frame_Video.set_halign(Gtk::Align::CENTER);
   m_Frame_Video.set_valign(Gtk::Align::CENTER);
-  pVBox->add(m_Frame_Video);
+  pVBox->append(m_Frame_Video);
 
   auto video = Gtk::make_managed<Gtk::Video>();
   video->set_resource("/images/gtk-logo.webm");
   video->get_media_stream()->set_loop();
-  m_Frame_Video.add(*video);
+  m_Frame_Video.set_child(*video);
 
   /* Widget paintable */
 
   pVBox = Gtk::make_managed<Gtk::Box>(Gtk::Orientation::VERTICAL, 8);
-  m_HBox.add(*pVBox);
+  m_HBox.append(*pVBox);
 
   m_Label_Paintable.set_markup("<u>Gtk::WidgetPaintable</u>");
-  pVBox->add(m_Label_Paintable);
+  pVBox->append(m_Label_Paintable);
 
-  pPicture = Gtk::make_managed<Gtk::Picture>();
+  auto pPicture = Gtk::make_managed<Gtk::Picture>();
   auto demo_window = DemoWindow::get_demo_window();
   if (demo_window)
   {
@@ -174,10 +178,10 @@ Example_Images::Example_Images()
   }
   pPicture->set_size_request(100, 100);
   pPicture->set_valign(Gtk::Align::START);
-  pVBox->add(*pPicture);
+  pVBox->append(*pPicture);
 
   /* Sensitivity control */
-  m_BaseVBox.add(m_ToggleButton);
+  m_BaseVBox.append(m_ToggleButton);
   m_ToggleButton.signal_toggled().connect(sigc::mem_fun(*this, &Example_Images::on_toggle_sensitivity));
 }
 
@@ -194,12 +198,37 @@ Example_Images::~Example_Images()
   }
 }
 
-void Example_Images::start_progressive_loading()
+void Example_Images::on_animation_timeout()
 {
-  Glib::signal_timeout().connect(sigc::mem_fun(*this, &Example_Images::on_timeout), 150);
+  auto delay = m_refPixbufAnimationIter->get_delay_time();
+  Glib::signal_timeout().connect_once(
+    sigc::mem_fun(*this, &Example_Images::on_animation_timeout), delay);
+
+  m_refPixbufAnimationIter->advance();
+  auto pixbuf = m_refPixbufAnimationIter->get_pixbuf();
+  auto texture = Gdk::Texture::create_for_pixbuf(pixbuf);
+  m_Picture_Animation.set_paintable(texture);
 }
 
-bool Example_Images::on_timeout()
+void Example_Images::init_message_dialog()
+{
+  if (!m_pMessageDialog)
+  {
+    m_pMessageDialog.reset(new Gtk::MessageDialog(
+      "", false, Gtk::MessageType::ERROR, Gtk::ButtonsType::CLOSE, true));
+    m_pMessageDialog->set_transient_for(*this);
+    m_pMessageDialog->set_hide_on_close(true);
+    m_pMessageDialog->signal_response().connect(
+      sigc::hide(sigc::mem_fun(*m_pMessageDialog, &Gtk::Widget::hide)));
+  }
+}
+
+void Example_Images::start_progressive_loading()
+{
+  Glib::signal_timeout().connect(sigc::mem_fun(*this, &Example_Images::on_progressive_timeout), 150);
+}
+
+bool Example_Images::on_progressive_timeout()
 {
   /* This shows off fully-paranoid error handling, so looks scary.
    * You could factor out the error handling code into a nice separate
@@ -217,12 +246,13 @@ bool Example_Images::on_timeout()
     }
     catch(const Glib::Error& error)
     {
+      init_message_dialog();
 
       Glib::ustring strMsg = "Failure reading image 'alphatest.png': ";
       strMsg += error.what();
 
-      Gtk::MessageDialog dialog(strMsg, false, Gtk::MessageType::ERROR, Gtk::ButtonsType::CLOSE);
-      dialog.run();
+      m_pMessageDialog->set_message(strMsg);
+      m_pMessageDialog->show();
 
       m_image_stream.reset();
 
@@ -235,11 +265,13 @@ bool Example_Images::on_timeout()
     }
     catch(const Glib::Error& error)
     {
+      init_message_dialog();
+
       Glib::ustring strMsg = "Failed to load image: ";
       strMsg += error.what();
 
-      Gtk::MessageDialog dialog(strMsg, false, Gtk::MessageType::ERROR, Gtk::ButtonsType::CLOSE);
-      dialog.run();
+      m_pMessageDialog->set_message(strMsg);
+      m_pMessageDialog->show();
 
       m_image_stream.reset();
 
@@ -261,11 +293,13 @@ bool Example_Images::on_timeout()
       }
       catch(const Glib::Error& error)
       {
+        init_message_dialog();
+
         Glib::ustring strMsg = "Failed to close image: ";
         strMsg += error.what();
 
-        Gtk::MessageDialog dialog(strMsg, false, Gtk::MessageType::ERROR, Gtk::ButtonsType::CLOSE);
-        dialog.run();
+        m_pMessageDialog->set_message(strMsg);
+        m_pMessageDialog->show();
 
         m_refPixbufLoader.reset();
 
@@ -283,11 +317,13 @@ bool Example_Images::on_timeout()
     }
     catch(const Glib::Error& error)
     {
+      init_message_dialog();
+
       Glib::ustring strMsg = "Unable to open image 'alphatest.png': ";
       strMsg += error.what();
 
-      Gtk::MessageDialog dialog(strMsg, false, Gtk::MessageType::ERROR, Gtk::ButtonsType::CLOSE);
-      dialog.run();
+      m_pMessageDialog->set_message(strMsg);
+      m_pMessageDialog->show();
 
       return false; // uninstall the timeout
     }
