@@ -14,6 +14,7 @@
 #include <gtkmm.h>
 #include <cmath>
 #include <algorithm>
+#include <memory>
 
 namespace
 {
@@ -59,6 +60,7 @@ protected:
   guint m_back_width = 0;
   guint m_back_height = 0;
   gint64 m_start_time = 0;
+  std::unique_ptr<Gtk::MessageDialog> m_pMessageDialog;
 };
 
 //Called by DemoWindow;
@@ -79,18 +81,27 @@ Example_Pixbufs::Example_Pixbufs()
     set_size_request(m_back_width, m_back_height);
     m_refPixbuf = Gdk::Pixbuf::create(Gdk::Colorspace::RGB, false, 8, m_back_width, m_back_height);
     m_DrawingArea.set_draw_func(sigc::mem_fun(*this, &Example_Pixbufs::on_drawingarea_draw));
-    add(m_DrawingArea);
+    set_child(m_DrawingArea);
 
     m_tick_id = m_DrawingArea.add_tick_callback(
         sigc::mem_fun(*this, &Example_Pixbufs::on_tick));
   }
   catch (const Glib::Error& error)
   {
+    if (!m_pMessageDialog)
+    {
+      m_pMessageDialog.reset(new Gtk::MessageDialog(
+        "", false, Gtk::MessageType::ERROR, Gtk::ButtonsType::CLOSE, true));
+      m_pMessageDialog->set_transient_for(*this);
+      m_pMessageDialog->set_hide_on_close(true);
+      m_pMessageDialog->signal_response().connect(
+        sigc::hide(sigc::mem_fun(*m_pMessageDialog, &Gtk::Widget::hide)));
+    }
+
     Glib::ustring strMsg = "Failed to load an image: ";
     strMsg += error.what();
-
-    Gtk::MessageDialog dialog(strMsg, false, Gtk::MessageType::ERROR, Gtk::ButtonsType::CLOSE);
-    dialog.run();
+    m_pMessageDialog->set_message(strMsg);
+    m_pMessageDialog->show();
   }
 }
 
