@@ -17,14 +17,12 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include <gtkmm/main.h>
+#include <gtkmm/application.h>
 #include "demowindow.h"
 
-int main (int argc, char *argv[])
+int main(int argc, char* argv[])
 {
   auto app = Gtk::Application::create();
 
-  DemoWindow window;
-
-  return app->run(window, argc, argv);
+  return app->make_window_and_run<DemoWindow>(argc, argv);
 }
