@@ -31,23 +31,29 @@
 #include <gdkmm/devicewithpad.h>
 #include <gdkmm/display.h>
 #include <gdkmm/displaymanager.h>
+#include <gdkmm/dragsurface.h>
+#include <gdkmm/dragsurfaceimpl.h>
 #include <gdkmm/drop.h>
-#include <gdkmm/events.h>
+#include <gdkmm/event.h>
 #include <gdkmm/frameclock.h>
 #include <gdkmm/general.h>
 #include <gdkmm/glcontext.h>
 #include <gdkmm/gltexture.h>
+#include <gdkmm/memorytexture.h>
 #include <gdkmm/monitor.h>
 #include <gdkmm/paintable.h>
 #include <gdkmm/pixbuf.h>
 #include <gdkmm/pixbufanimation.h>
 #include <gdkmm/pixbufformat.h>
 #include <gdkmm/pixbufloader.h>
+#include <gdkmm/popup.h>
+#include <gdkmm/popupsurfaceimpl.h>
 #include <gdkmm/rectangle.h>
 #include <gdkmm/seat.h>
 #include <gdkmm/snapshot.h>
 #include <gdkmm/surface.h>
 #include <gdkmm/texture.h>
-#include <gdkmm/types.h>
+#include <gdkmm/toplevel.h>
+#include <gdkmm/toplevelsurfaceimpl.h>
 
 #endif /* _GDKMM_GDKMM_H_ */
