@@ -24,7 +24,7 @@
  *
  * @section description Description
  *
- * gtkmm is the official C++ interface for the popular GUI library GTK+.
+ * gtkmm is the official C++ interface for the popular GUI library GTK.
  * Highlights include typesafe callbacks, and a comprehensive set of widgets
  * that are easily extensible via inheritance.
  *
@@ -32,17 +32,16 @@
  * @ref TextView "TextView".
  *
  * See also the
- * <a href="http://library.gnome.org/devel/gtkmm-tutorial/stable/">Programming
+ * <a href="https://gnome.pages.gitlab.gnome.org/gtkmm-documentation/">Programming
  * with gtkmm</a> book.
  *
- *
  * @section features Features
  *
- * - GTK+’s mature, capable set of @ref Widgets widgets. See
- *   <a href="http://www.gtk.org/">the GTK+ website</a> for more information.
+ * - GTK’s mature, capable set of @ref Widgets "widgets". See
+ *   <a href="https://www.gtk.org/">the GTK website</a> for more information.
  * - Use inheritance to derive custom widgets.
  * - Type-safe signal handlers (slots), in standard C++, using
- *   <a href="http://libsigc.sourceforge.net/">libsigc++</a>.
+ *   <a href="https://libsigcplusplus.github.io/libsigcplusplus/">libsigc++</a>.
  * - Polymorphism.
  * - Use of the Standard C++ Library, including strings, containers and
  *   iterators.
@@ -66,6 +65,20 @@
  * @code
  * g++ program.cc -o program  `pkg-config --cflags --libs gtkmm-4.0`
  * @endcode
+ * If your version of g++ is not C++17-compliant by default,
+ * add the @c -std=c++17 option.
+ *
+ * If you use <a href="https://mesonbuild.com/">Meson</a>, include the following
+ * in @c meson.build:
+ * @code
+ * gtkmm_dep = dependency('gtkmm-4.0')
+ * program_name = 'program'
+ * cpp_sources = [ 'program.cc' ]
+ * executable(program_name,
+ *   cpp_sources,
+ *   dependencies: gtkmm_dep
+ * )
+ * @endcode
  *
  * Alternatively, if using autoconf, use the following in @c configure.ac:
  * @code
@@ -91,9 +104,8 @@ extern const int gtkmm_micro_version;
 
 #include <gtkmm/object.h>
 #include <gtkmm/aboutdialog.h>
+#include <gtkmm/accelerator.h>
 #include <gtkmm/accelkey.h>
-#include <gtkmm/accelmap.h>
-#include <gtkmm/accelgroup.h>
 #include <gtkmm/actionable.h>
 #include <gtkmm/actionbar.h>
 #include <gtkmm/adjustment.h>
@@ -104,8 +116,8 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/applicationwindow.h>
 #include <gtkmm/aspectframe.h>
 #include <gtkmm/assistant.h>
-#include <gtkmm/bin.h>
 #include <gtkmm/binlayout.h>
+#include <gtkmm/boolfilter.h>
 #include <gtkmm/border.h>
 #include <gtkmm/box.h>
 #include <gtkmm/boxlayout.h>
@@ -130,32 +142,39 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/colorbutton.h>
 #include <gtkmm/colorchooser.h>
 #include <gtkmm/colorchooserdialog.h>
+#include <gtkmm/columnview.h>
 #include <gtkmm/combobox.h>
 #include <gtkmm/comboboxtext.h>
 #include <gtkmm/constraintlayout.h>
-#include <gtkmm/container.h>
 #include <gtkmm/cssprovider.h>
 #include <gtkmm/csssection.h>
 #include <gtkmm/dialog.h>
+#include <gtkmm/directorylist.h>
+#include <gtkmm/dragicon.h>
 #include <gtkmm/dragsource.h>
 #include <gtkmm/drawingarea.h>
+#include <gtkmm/dropcontrollermotion.h>
+#include <gtkmm/dropdown.h>
 #include <gtkmm/droptarget.h>
-#include <gtkmm/editable.h>
+#include <gtkmm/droptargetasync.h>
+#include <gtkmm/editablelabel.h>
 #include <gtkmm/emojichooser.h>
 #include <gtkmm/entry.h>
 #include <gtkmm/expander.h>
 #include <gtkmm/enums.h>
 #include <gtkmm/eventcontroller.h>
+#include <gtkmm/eventcontrollerfocus.h>
 #include <gtkmm/eventcontrollerkey.h>
 #include <gtkmm/eventcontrollermotion.h>
 #include <gtkmm/eventcontrollerscroll.h>
 #include <gtkmm/filechooser.h>
-#include <gtkmm/filechooserbutton.h>
 #include <gtkmm/filechooserdialog.h>
 #include <gtkmm/filechoosernative.h>
 #include <gtkmm/filechooserwidget.h>
 #include <gtkmm/filefilter.h>
+#include <gtkmm/filterlistmodel.h>
 #include <gtkmm/fixed.h>
+#include <gtkmm/flattenlistmodel.h>
 #include <gtkmm/flowbox.h>
 #include <gtkmm/flowboxchild.h>
 #include <gtkmm/fontbutton.h>
@@ -177,11 +196,13 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/grid.h>
 #include <gtkmm/gridlayout.h>
 #include <gtkmm/gridlayoutchild.h>
+#include <gtkmm/gridview.h>
 #include <gtkmm/headerbar.h>
 #include <gtkmm/icontheme.h>
 #include <gtkmm/iconview.h>
 #include <gtkmm/image.h>
 #include <gtkmm/infobar.h>
+#include <gtkmm/inscription.h>
 #include <gtkmm/calendar.h>
 #include <gtkmm/label.h>
 #include <gtkmm/layoutchild.h>
@@ -190,15 +211,19 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/listbox.h>
 #include <gtkmm/listboxrow.h>
 #include <gtkmm/liststore.h>
+#include <gtkmm/listview.h>
 #include <gtkmm/listviewtext.h>
 #include <gtkmm/linkbutton.h>
-#include <gtkmm/main.h>
 #include <gtkmm/mediacontrols.h>
 #include <gtkmm/mediafile.h>
 #include <gtkmm/menubutton.h>
 #include <gtkmm/messagedialog.h>
+#include <gtkmm/multifilter.h>
+#include <gtkmm/multiselection.h>
+#include <gtkmm/multisorter.h>
 #include <gtkmm/noselection.h>
 #include <gtkmm/notebook.h>
+#include <gtkmm/numericsorter.h>
 #include <gtkmm/object.h>
 #include <gtkmm/overlay.h>
 #include <gtkmm/padcontroller.h>
@@ -225,7 +250,6 @@ extern const int gtkmm_micro_version;
 # include <gtkmm/printunixdialog.h>
 #endif
 #include <gtkmm/progressbar.h>
-#include <gtkmm/radiobutton.h>
 #include <gtkmm/range.h>
 #include <gtkmm/recentinfo.h>
 #include <gtkmm/recentmanager.h>
@@ -237,21 +261,31 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/searchbar.h>
 #include <gtkmm/searchentry.h>
 #include <gtkmm/separator.h>
+#include <gtkmm/selectionfiltermodel.h>
+#include <gtkmm/selectionlistmodelimpl.h>
 #include <gtkmm/settings.h>
+#include <gtkmm/shortcutcontroller.h>
 #include <gtkmm/shortcutlabel.h>
 #include <gtkmm/shortcutsgroup.h>
 #include <gtkmm/shortcutssection.h>
 #include <gtkmm/shortcutsshortcut.h>
 #include <gtkmm/shortcutswindow.h>
+#include <gtkmm/signallistitemfactory.h>
 #include <gtkmm/singleselection.h>
 #include <gtkmm/sizegroup.h>
+#include <gtkmm/slicelistmodel.h>
 #include <gtkmm/snapshot.h>
+#include <gtkmm/sortlistmodel.h>
 #include <gtkmm/spinbutton.h>
 #include <gtkmm/spinner.h>
 #include <gtkmm/stack.h>
 #include <gtkmm/stacksidebar.h>
 #include <gtkmm/stackswitcher.h>
 #include <gtkmm/statusbar.h>
+#include <gtkmm/stringfilter.h>
+#include <gtkmm/stringlist.h>
+#include <gtkmm/stringobject.h>
+#include <gtkmm/stringsorter.h>
 #include <gtkmm/stylecontext.h>
 #include <gtkmm/switch.h>
 #include <gtkmm/text.h>
@@ -264,6 +298,8 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/textview.h>
 #include <gtkmm/togglebutton.h>
 #include <gtkmm/tooltip.h>
+#include <gtkmm/treeexpander.h>
+#include <gtkmm/treelistmodel.h>
 #include <gtkmm/treemodel.h>
 #include <gtkmm/treemodelfilter.h>
 #include <gtkmm/treemodelsort.h>
@@ -279,6 +315,8 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/volumebutton.h>
 #include <gtkmm/widget.h>
 #include <gtkmm/widgetpaintable.h>
+#include <gtkmm/windowcontrols.h>
 #include <gtkmm/window.h>
+#include <gtkmm/windowhandle.h>
 
 #endif /* #ifndef GTKMM_H */
