@@ -1,4 +1,5 @@
 #include <gtkmm.h>
+#include <gtkmm/init.h>
 #include <iostream>
 #include <cassert>
 #include <cstdlib>
@@ -34,7 +35,7 @@ test_assignment_to_const() {
 int main(int /* argc */, char** /* argv */)
 {
   gtk_init();
-  Gtk::Main::init_gtkmm_internals();
+  Gtk::init_gtkmm_internals();
 
   test_const_conversion();
   test_assignment_from_const();
