@@ -8,19 +8,14 @@ source "$(dirname "$0")/init_generate.sh"
 out_dir="$root_dir/gtk/src"
 
 params="--with-properties --no-recursion"
-if [ "$gtk_build_prefix" != "$gtk_source_prefix" ]; then
-  gtk_build_dir="$gtk_build_prefix"/gtk
-fi
-for dir in "$gtk_source_prefix"/{gtk,gtk/deprecated} "$gtk_build_dir"; do
+for dir in "$gtk_source_prefix"/{gtk,gtk/css,gtk/deprecated} "$gtk_build_prefix"/{gtk,gtk/css}; do
   if [ -d "$dir" ]; then
     params="$params -s $dir"
   fi
 done
 
-# Exclude gtkclipboard-quartz.c and gtkdnd-quartz.c. Function descriptions in
-# those files can replace better descriptions in gtkclipboard.c and gtkdnd.c,
-# if they are processed.
-params="$params -x $gtk_source_prefix/gtk/gtkclipboard-quartz.c"
+# Exclude gtkdnd-quartz.c. Function descriptions in gtkdnd-quartz.c can
+# replace better descriptions in gtkdnd.c, if gtkdnd-quartz.c is processed.
 params="$params -x $gtk_source_prefix/gtk/gtkdnd-quartz.c"
 
 "$gen_docs" $params > "$out_dir/gtk_docs.xml"
